# Tandem Repeat Annotation Library

TRAL is a highly modularized, flexible sequence tandem repeats annotation Python2/3 library.

  - Large scale annotation of tandem repeats with *de novo* detectors, and sequence profile models
  - Statistical significance testing, overlap detection, and filtering of annotations
  - Refinement of tandem repeat annotations with circular profile hidden Markov models
  - User-defined output formats

The source code is [documented on GitHub IO].

### Version
0.3.0


### Installation

TRAL is available on [Pypi] and can be installed with [pip] for Python>2.7 and Python>3.2:

```sh
$ pip install tral
```


### License

GNU

[documented on GitHub IO]:http://elkeschaper.github.io/tral/
[Pypi]:https://pypi.python.org/pypi
[pip]:https://pip.pypa.io/en/latest/